bias: Model Bias

View source: R/stdMetrics.R

biasR Documentation

Model Bias

Description

Model Bias

Usage

bias(trues, preds)

Arguments

trues

Target values from a test set of a given data set. Should be a vector and have the same size as the variable preds

preds

Predicted values given a certain test set of a given data set. Should be a vector and have the same size as the variable trues

Value

Value for model bias


IRon documentation built on Nov. 5, 2025, 5:50 p.m.

Related to bias in IRon...