mse: Mean Squared Error

View source: R/stdMetrics.R

mseR Documentation

Mean Squared Error

Description

Mean Squared Error

Usage

mse(trues, preds)

Arguments

trues

Target values from a test set of a given data set. Should be a vector and have the same size as the variable preds

preds

Predicted values given a certain test set of a given data set. Should be a vector and have the same size as the variable trues

Value

Value for the mean squared error


IRon documentation built on Nov. 5, 2025, 5:50 p.m.

Related to mse in IRon...