variance: Model Variance

View source: R/stdMetrics.R

varianceR Documentation

Model Variance

Description

Model Variance

Usage

variance(preds)

Arguments

preds

Predicted values given a certain test set of a given data set. Should be a vector and have the same size as the variable trues

Value

Value for model variance


IRon documentation built on Nov. 5, 2025, 5:50 p.m.

Related to variance in IRon...